pub enum BaseBaselineError {
GitMissing(String),
NotARepository,
RefUnavailable,
GitFailed(String),
}Expand description
Why the baseline at the base ref could not be read.
Variants
GitMissing(String)
git could not be started.
NotARepository
The baseline is not in a git work tree.
Git cannot resolve the ref to a commit, typically because a shallow clone did not fetch it.
GitFailed(String)
Git failed for another reason.