pub struct BaselineGrowth {
pub categories: Vec<GrownCategory>,
}Expand description
The keys that a baseline has and its version at the base ref does not have.
Fields
categories: Vec<GrownCategory>One item per category that grew, sorted by category name.
Implementations