pub struct ParseCacheStatus {
pub rejection: Option<CacheRejection>,
pub size_bytes: Option<u64>,
}Expand description
On-disk state of the extraction cache for one project.
Fields
rejection: Option<CacheRejection>Why the cache would not be reused by a run with this configuration, or
None when a run would load it.
size_bytes: Option<u64>Size of cache.bin on disk, when the file exists.