Module changed_files

Module changed_files 

Changed-file helpers owned by the engine boundary.

Enums

ChangedFilesError
Classification of a changed-file git failure.

Constants

AMBIENT_GIT_ENV_VARS
Environment variables that describe an enclosing git operation’s repository state and should not leak into fallow-owned git subprocesses.

Functions

changed_files
Resolve changed files for a git ref relative to a project root.
clear_ambient_git_env
Strip ambient git repository-state environment variables from a Command.
filter_duplication_by_changed_files
Scope duplication groups to clone groups touching at least one changed file.
filter_results_by_changed_files
Scope dead-code results to findings affected by changed files.
get_changed_files
Get changed files if git can resolve them, otherwise return None.
resolve_git_common_dir
Resolve the canonical git common directory for cwd.
resolve_git_toplevel
Resolve the canonical git toplevel for cwd.
set_spawn_hook
Install a spawn-hook for changed-file git subprocesses.
try_get_changed_diff
Return the raw git diff for a ref.
try_get_changed_files
Get files changed since a git ref.
try_get_changed_files_with_toplevel
Get changed files and the git toplevel used to resolve them.
validate_git_ref
Validate a user-supplied git ref before passing it to git.

Type Aliases

ChangedFilesSpawnHook
Function pointer signature used to intercept short-running git subprocesses spawned by changed-file helpers.