changed_files

Function changed_files 

pub fn changed_files(
    root: &Path,
    git_ref: &str,
) -> Result<FxHashSet<PathBuf>, ChangedFilesError>
Resolve changed files for a git ref relative to a project root.

Errors

Returns an error when git cannot resolve the ref or repository state.