Cross-reference helpers exposed through the engine boundary.
Structs
- Combined
Finding - A combined finding where a clone instance overlaps with a dead-code issue.
- Cross
Reference Result - Result of cross-referencing duplication with dead-code analysis.
Enums
- Dead
Code Kind - The type of dead code that overlaps with a clone instance.
Functions
- cross_
reference - Cross-reference duplication findings with dead-code analysis results.