pub struct CombinedFinding {
pub clone_instance: CloneInstance,
pub dead_code_kind: DeadCodeKind,
pub group_index: usize,
}Expand description
A combined finding where a clone instance overlaps with a dead-code issue.
Fields
clone_instance: CloneInstanceThe clone instance that is also unused.
dead_code_kind: DeadCodeKindWhat kind of dead code overlaps with this clone.
group_index: usizeClone group index for associating with the parent group.