resolve_security_finding_severity

Function resolve_security_finding_severity 

pub fn resolve_security_finding_severity(
    config: &ResolvedConfig,
    finding: &SecurityFinding,
) -> Severity
The severity of finding for its own path.

The overrides that match the path of the finding apply in the same way as for dead-code findings.