pub fn security_rules_can_error(config: &ResolvedConfig) -> boolExpand description
Whether a security rule is error at the top level or in an override.
pub fn security_rules_can_error(config: &ResolvedConfig) -> boolWhether a security rule is error at the top level or in an override.