pub struct SeveritySource<'a> { /* private fields */ }Expand description
The rules that give a finding its severity.
Implementations
Sourceimpl<'a> SeveritySource<'a>
impl<'a> SeveritySource<'a>
Sourcepub fn from_config(config: &'a ResolvedConfig) -> Self
pub fn from_config(config: &'a ResolvedConfig) -> Self
The rules of config, with its overrides for file-scoped findings.
Sourcepub fn new(
base: &'a RulesConfig,
config: Option<&'a ResolvedConfig>,
promote_warns: bool,
) -> Self
pub fn new( base: &'a RulesConfig, config: Option<&'a ResolvedConfig>, promote_warns: bool, ) -> Self
Explicit base rules, with the overrides of config when it has any.
promote_warns raises a warn that an override resolves to error.
The caller promotes base itself.