pub struct RetirementBuild {
pub report: FlagRetirementReport,
pub diagnostics: Vec<WorkspaceDiagnosticKind>,
}Expand description
A retirement report and the reasons that ages are missing.
Fields
report: FlagRetirementReportThe report.
diagnostics: Vec<WorkspaceDiagnosticKind>Why no age was measured, when git history was not available.