pub struct VendorExport {
pub source: String,
pub exported_at: String,
pub display_path: String,
pub flags: Vec<VendorFlag>,
}Expand description
A valid vendor export.
Fields
source: StringThe vendor name, for example launchdarkly.
exported_at: StringWhen the export was made, as the file gives it.
display_path: StringThe export path for evidence: relative to the root when the file is inside it, else the file name only.
flags: Vec<VendorFlag>The flags, in file order.