Feature flag analysis owned by the engine boundary.
Structs
- Feature
Flags Analysis - Typed result from running feature flag analysis.
Functions
- analyze_
feature_ flags_ for_ retirement - Run feature flag analysis and also collect the facts that the flag retirement report reads.
- analyze_
feature_ flags_ with_ session - Run feature flag analysis with a reusable analysis session.
- analyze_
feature_ flags_ with_ session_ and_ results - Run feature flag analysis while reusing dead-code results from the same session.
- builtin_
env_ prefixes - Built-in environment variable prefixes treated as feature flags.
- builtin_
sdk_ providers - Distinct built-in SDK provider labels, in declaration order.