Module guard

Module guard 

Typed guard report assembly for pre-edit architecture guidance.

Enums

GuardError
Error returned when a guard target cannot be represented safely.

Functions

build_guard_report
Build a typed guard report for one or more target files.