pub struct IstanbulCoverage { /* private fields */ }Expand description
Loaded Istanbul coverage data, keyed by canonical file path.
Implementations
Sourceimpl IstanbulCoverage
impl IstanbulCoverage
Sourcepub fn get(&self, path: &Path) -> Option<&IstanbulFileCoverage>
pub fn get(&self, path: &Path) -> Option<&IstanbulFileCoverage>
Get coverage data for a file path.
Sourcepub fn file_count(&self) -> usize
pub fn file_count(&self) -> usize
How many files the coverage map describes, joined or not.
Sourcepub const fn format(&self) -> CoverageInputFormat
pub const fn format(&self) -> CoverageInputFormat
The input format the coverage was read from.