pub struct InlineComplexity {
pub path: PathBuf,
pub name: String,
pub line: u32,
pub col: u32,
pub cyclomatic: u16,
pub cognitive: u16,
pub exceeds_cyclomatic: bool,
pub exceeds_cognitive: bool,
}Expand description
One function above a complexity threshold, for an editor code lens.
Fields
path: PathBufAbsolute path of the file that declares the function.
name: StringFunction name as extracted from the source.
line: u32One-based line of the function declaration.
col: u32Zero-based column of the function declaration.
cyclomatic: u16Measured cyclomatic complexity.
cognitive: u16Measured cognitive complexity.
exceeds_cyclomatic: boolThe function is above the effective cyclomatic threshold.
exceeds_cognitive: boolThe function is above the effective cognitive threshold.