pub struct AggregatedPluginResult { /* private fields */ }Expand description
Aggregated results from all active plugins for a project.
Implementations
Sourceimpl AggregatedPluginResult
impl AggregatedPluginResult
Sourcepub fn active_plugins(&self) -> &[String]
pub fn active_plugins(&self) -> &[String]
Names of active plugins.
Sourcepub fn merge_active_plugins_from(&mut self, other: &Self)
pub fn merge_active_plugins_from(&mut self, other: &Self)
Merge active plugin names from another result, preserving insertion order.