Module project_config

Module project_config 

Project config resolution owned by the engine boundary.

Structs

ProductionFlags
The production flags of one run: the global --production override and one override per analysis (--production-dead-code, --production-health, --production-dupes).
ProductionModes
The production mode of each analysis of one run.
ProjectConfig
Resolved project config plus the config file path when one was loaded.
ProjectConfigOptions
Scalar config-loading knobs for one analysis family.
ProjectConfigReadiness
Resolved project configuration plus doctor-specific plugin diagnostics.

Functions

config_for_project
Resolve the analysis config for a project.
config_for_project_analysis
Resolve config for a specific analysis without depending on the CLI crate.
config_for_project_readiness
Resolve project configuration and collect typed readiness diagnostics for plugin resources named explicitly by the user configuration.
config_for_project_with_load_options
Resolve project config with an explicit inheritance trust policy.