pub fn config_for_project(
root: &Path,
config_path: Option<&Path>,
) -> EngineResult<ProjectConfig>Expand description
Resolve the analysis config for a project.
Errors
Returns an error when an explicit config cannot be loaded or automatic config discovery finds an invalid config.