Source parsing contracts owned by the engine boundary.
Modules
- inventory
- Source inventory walking for coverage and upload surfaces.
- similar_
code - On-demand, transient function extraction for local similar-code inference.
Structs
- Module
Info - Extracted module information from a single file.
- Parse
Result - Result of parsing all files, including incremental cache statistics.
- Source
Read Failure - A discovered source that could not be read as UTF-8 text.