pub fn walk_source_with_complexity(
path: &Path,
source: &str,
) -> (Vec<InventoryEntry>, FxHashMap<String, InventoryComplexity>)Expand description
Walk source once and emit inventory entries plus static complexity by source hash.
pub fn walk_source_with_complexity(
path: &Path,
source: &str,
) -> (Vec<InventoryEntry>, FxHashMap<String, InventoryComplexity>)Walk source once and emit inventory entries plus static complexity by source hash.