#[non_exhaustive]pub enum SimilarCodeFunctionKind {
FunctionDeclaration,
FunctionExpression,
ArrowFunction,
ClassMethod,
ObjectMethod,
}Expand description
Supported source form for an extracted similar-code function.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FunctionDeclaration
A top-level named function declaration.
FunctionExpression
A top-level identifier binding or default export using a function expression.
ArrowFunction
A top-level identifier binding or default export using an arrow function.
ClassMethod
A statically named ordinary method on a top-level named class.
ObjectMethod
A statically named ordinary method on a top-level bound object literal.