#[non_exhaustive]pub enum SimilarCodeSideEffectHint {
PureLooking,
MayHaveSideEffects,
Unknown,
}Expand description
Conservative syntactic hint about possible function side effects.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PureLooking
No explicit effectful construct was present in a reliably parsed body.
MayHaveSideEffects
The body contains a call, write, throw, await, member access, or similar construct.
Unknown
Parser recovery made the syntactic classification unreliable.