pub fn extract(
path: &Path,
source: &str,
limits: SimilarCodeExtractionLimits,
) -> SimilarCodeExtractionExpand description
Extract bounded named functions without touching the normal parse cache.
pub fn extract(
path: &Path,
source: &str,
limits: SimilarCodeExtractionLimits,
) -> SimilarCodeExtractionExtract bounded named functions without touching the normal parse cache.