pub struct SimilarCodeExtractionSkip {
pub reason: SimilarCodeExtractionSkipReason,
pub count: usize,
}Expand description
Counted omission or recovery evidence for one stable extraction reason.
Fields
reason: SimilarCodeExtractionSkipReasonStable reason.
count: usizeNumber of functions or diagnostics represented by the reason.