pub fn is_test_path_str(root: &Path, relative: &str) -> boolExpand description
Whether a project-relative path string is test code or test support.
The string form of is_test_path for callers that hold
forward-slash path strings.
pub fn is_test_path_str(root: &Path, relative: &str) -> boolWhether a project-relative path string is test code or test support.
The string form of is_test_path for callers that hold
forward-slash path strings.