pub fn worker_pool_builder(threads: usize) -> ThreadPoolBuilderExpand description
Rayon pool builder preconfigured with the analysis worker stack size.
pub fn worker_pool_builder(threads: usize) -> ThreadPoolBuilderRayon pool builder preconfigured with the analysis worker stack size.