trace_error_with_session

Function trace_error_with_session 

pub fn trace_error_with_session(
    session: &AnalysisSession,
    input: &str,
    source: String,
) -> EngineResult<ErrorTrace>
Resolve a stack trace through an existing analysis session.

Errors

Returns an error if parsing or graph construction fails.