pub fn validate_root(root: &Path) -> Result<PathBuf, String>
Canonicalize a project root and require it to be an existing directory.
Returns a message when the path cannot be canonicalized or is not a directory.