install

Function install 

pub fn install(store: Option<Arc<WarmParseStore>>)
Make store the store of each session that this process creates from now on. None removes the store, so new sessions parse as before.

Only a long-lived process that runs many analyses of the same project installs a store, such as the MCP server. A session keeps the store that was installed when the session was created.