pub struct WarmParseLimits {
pub max_entries: usize,
pub max_retained_bytes: u64,
}Expand description
Memory limits of a WarmParseStore.
Fields
max_entries: usizeThe most parsed file lists that the store keeps. The store removes the least recently used list first.
max_retained_bytes: u64The limit on the estimated memory, in bytes, of the kept modules of all file lists. The estimate is 12 bytes for each source byte, plus the size of one module struct for each file. A file list with an estimate over this limit is not kept.