Module workspace_scope

Module workspace_scope 

Workspace scoping owned by the engine boundary.

Enums

WorkspaceScopeError
Typed workspace-scope failure. Surfaces decide their own wording.
WorkspaceScopeMode
User-facing workspace scope mode.

Functions

resolve_workspace_scope_roots
Resolve either explicit or changed workspace scope against discovered metadata.
resolve_workspace_scope_roots_for_project
Resolve either explicit or changed workspace scope by discovering workspace metadata first.