pub fn resolve_changed_workspace_roots(
root: &Path,
git_ref: &str,
workspaces: &[WorkspaceInfo],
) -> Result<Vec<PathBuf>, WorkspaceScopeError>Expand description
Resolve workspace roots that contain files changed since git_ref.
Errors
Returns a typed scope error when no workspaces are available or git fails.