confine

Function confine 

pub fn confine(cwd: PathBuf, paths: WriteScope, config: WriteScope)
Record the scopes that later writes are checked against. The first call wins. Without a call, writes are not confined, but they still do not follow a symlink at the final component that appears after the path was resolved.