Finding-count and finding-identity baselines for suppressing known issues across runs.
Structs
- Baseline
Data - Baseline data for comparison.
- Baseline
Deltas - Deltas between current analysis results and a saved baseline.
- Category
Delta - Per-category delta between current results and a baseline.
- Duplication
Baseline Data - Baseline data for duplication comparison.
- Health
Baseline Count - Serialized per-bucket finding tally inside a health baseline file.
- Health
Baseline Data - Baseline data for health (complexity) comparison.
Enums
- Health
Baseline Mode - How a saved health baseline is matched against current findings.
Functions
- filter_
new_ clone_ groups - Filter a duplication report to only include clone groups not present in the baseline.
- filter_
new_ issues - Filter results to only include issues not present in the baseline.
- recompute_
stats - Recompute duplication statistics after filtering (baseline or
--changed-since).