Structs
- Baseline
Data - Baseline data for comparison.
- Baseline
Deltas - Deltas between current analysis results and a saved baseline.
- Category
Delta - Per-category delta between current results and a baseline.
- Duplication
Baseline Data - Baseline data for duplication comparison.
- Health
Baseline Count - Health
Baseline Data - Baseline data for health (complexity) comparison.
Functions
- filter_
new_ clone_ groups - Filter a duplication report to only include clone groups not present in the baseline.
- filter_
new_ health_ findings - Filter health findings to only include those not present in the baseline.
- filter_
new_ health_ targets - Filter refactoring targets to only include those not present in the baseline.
- filter_
new_ issues - Filter results to only include issues not present in the baseline.
- filter_
new_ runtime_ coverage_ findings - recompute_
stats - Recompute duplication statistics after filtering (baseline or
--changed-since).