Changed-file helpers owned by the engine boundary.
Enums
- Changed
Files Error - Classification of a changed-file git failure.
Constants
- AMBIENT_
GIT_ ENV_ VARS - Environment variables that describe an enclosing git operation’s repository state and should not leak into fallow-owned git subprocesses.
Functions
- changed_
files - Resolve changed files for a git ref relative to a project root.
- clear_
ambient_ git_ env - Strip ambient git repository-state environment variables from a
Command. - filter_
duplication_ by_ changed_ files - Scope duplication groups to clone groups touching at least one changed file.
- filter_
results_ by_ changed_ files - Scope dead-code results to findings affected by changed files.
- get_
changed_ files - Get changed files if git can resolve them, otherwise return
None. - resolve_
git_ common_ dir - Resolve the canonical git common directory for
cwd. - resolve_
git_ toplevel - Resolve the canonical git toplevel for
cwd. - set_
spawn_ hook - Install a spawn-hook for changed-file git subprocesses.
- try_
get_ changed_ diff - Return the raw git diff for a ref.
- try_
get_ changed_ files - Get files changed since a git ref.
- try_
get_ changed_ files_ with_ toplevel - Get changed files and the git toplevel used to resolve them.
- validate_
git_ ref - Validate a user-supplied git ref before passing it to git.
Type Aliases
- Changed
Files Spawn Hook - Function pointer signature used to intercept short-running git subprocesses spawned by changed-file helpers.