pub fn parse_flag_state(
bytes: &[u8],
display_path: String,
) -> Result<VendorExport, FlagStateError>Expand description
Parse and check the bytes of an export.
Errors
Returns an error when the bytes are not valid JSON in the schema, when
schema_version is not FLAG_STATE_SCHEMA_VERSION, when exported_at
has no YYYY-MM-DD date, or when a key is empty or occurs two times.