Typed guard report assembly for pre-edit architecture guidance.
Enums
- Guard
Error - Error returned when a guard target cannot be represented safely.
Functions
- build_
guard_ report - Build a typed guard report for one or more target files.