Project config resolution owned by the engine boundary.
Structs
- Production
Flags - The production flags of one run: the global
--productionoverride and one override per analysis (--production-dead-code,--production-health,--production-dupes). - Production
Modes - The production mode of each analysis of one run.
- Project
Config - Resolved project config plus the config file path when one was loaded.
- Project
Config Options - Scalar config-loading knobs for one analysis family.
- Project
Config Readiness - Resolved project configuration plus doctor-specific plugin diagnostics.
Functions
- config_
for_ project - Resolve the analysis config for a project.
- config_
for_ project_ analysis - Resolve config for a specific analysis without depending on the CLI crate.
- config_
for_ project_ readiness - Resolve project configuration and collect typed readiness diagnostics for plugin resources named explicitly by the user configuration.
- config_
for_ project_ with_ load_ options - Resolve project config with an explicit inheritance trust policy.