Module project_config

Module project_config 

Project config resolution owned by the engine boundary.

Structs

ProjectConfig
Resolved project config plus the config file path when one was loaded.
ProjectConfigOptions
Scalar config-loading knobs for one analysis family.

Functions

config_for_project
Resolve the analysis config for a project.
config_for_project_analysis
Resolve config for a specific analysis without depending on the CLI crate.
default_project_config
resolve_cache_max_size_bytes
Resolve the parse-cache size limit for a resolved config.