Project config resolution owned by the engine boundary.
Structs
- Project
Config - Resolved project config plus the config file path when one was loaded.
- Project
Config Options - Scalar config-loading knobs for one analysis family.
Functions
- config_
for_ project - Resolve the analysis config for a project.
- config_
for_ project_ analysis - Resolve config for a specific analysis without depending on the CLI crate.
- default_
project_ config - resolve_
cache_ max_ size_ bytes - Resolve the parse-cache size limit for a resolved config.