Engine-owned repository reference probes and temporary repo views.
Structs
- Resolved
Audit Base - Resolved base ref for changed-code audit.
- Temporary
Base Worktree - Temporary detached worktree for comparing audit results against a base ref.
Functions
- auto_
detect_ audit_ base_ ref - Auto-detect the base ref used by changed-code audit.
- base_
analysis_ root - Resolve the analysis root inside a detached base worktree.
- current_
user_ identities - Git identities for the current user in forms useful for self-routing.
- default_
workspace_ ref - Resolve a concrete
--changed-workspacesref for project-level next steps. - default_
workspace_ ref_ for_ workspaces - Resolve a concrete
--changed-workspacesref using existing workspace data. - short_
head_ sha - Short SHA for the current HEAD.