Module source

Module source 

Source parsing contracts owned by the engine boundary.

Modules

inventory
Source inventory walking for coverage and upload surfaces.
similar_code
On-demand, transient function extraction for local similar-code inference.

Structs

ModuleInfo
Extracted module information from a single file.
ParseResult
Result of parsing all files, including incremental cache statistics.
SourceReadFailure
A discovered source that could not be read as UTF-8 text.