Module workspace_scope

Module workspace_scope 

Workspace scoping owned by the engine boundary.

Enums

WorkspaceScopeError
Typed workspace-scope failure. Surfaces decide their own wording.
WorkspaceScopeMode
User-facing workspace scope mode.

Functions

resolve_changed_workspace_roots
Resolve workspace roots that contain files changed since git_ref.
resolve_changed_workspace_roots_for_project
Resolve changed workspace roots by discovering workspace metadata first.
resolve_workspace_filter_roots
Resolve explicit workspace filters against known workspace metadata.
resolve_workspace_filter_roots_for_project
Resolve explicit workspace filters by discovering workspace metadata first.
resolve_workspace_scope_roots
Resolve either explicit or changed workspace scope against discovered metadata.
resolve_workspace_scope_roots_for_project
Resolve either explicit or changed workspace scope by discovering workspace metadata first.