resolve_changed_workspace_roots

Function resolve_changed_workspace_roots 

pub fn resolve_changed_workspace_roots(
    root: &Path,
    git_ref: &str,
    workspaces: &[WorkspaceInfo],
) -> Result<Vec<PathBuf>, WorkspaceScopeError>
Resolve workspace roots that contain files changed since git_ref.

Errors

Returns a typed scope error when no workspaces are available or git fails.