pub fn resolve_workspace_scope_roots(
root: &Path,
workspace: Option<&[String]>,
changed_workspaces: Option<&str>,
workspaces: &[WorkspaceInfo],
) -> Result<Option<Vec<PathBuf>>, WorkspaceScopeError>Expand description
Resolve either explicit or changed workspace scope against discovered metadata.
Errors
Returns a typed scope error when the selection is invalid or git cannot resolve changed files.